@@ -36,9 +36,13 @@ class Tag2Dcm:
 
     def set_output_dir(self, output_dir):
         if not os.path.isdir(output_dir):
-            raise RuntimeError(f'Output directory {output_dir} does not exist')
+            print(f'Output directory {output_dir} does not exist, creating it...')
+            os.makedirs(output_dir, exist_ok=False)
         self.output_dir = output_dir
 
+    def get_output_dir(self):
+        return self.output_dir
+
     def set_copy_original_dcm_file_to_output_dir(self, copy_original_dcm_file_to_output_dir):
         self.copy_original_dcm_file_to_output_dir = copy_original_dcm_file_to_output_dir
 
@@ -48,6 +52,9 @@ class Tag2Dcm:
     def set_png_figure_size(self, png_figure_size):
         self.png_figure_size = png_figure_size
 
+    def get_png_figure_size(self):
+        return self.png_figure_size
+
     def set_create_pngs(self, create_pngs):
         self.create_pngs = create_pngs
 
@@ -81,16 +88,12 @@ class Tag2Dcm:
 
     def execute(self):
         p = pydicom.dcmread(self.dcm_file)
-        try:
-            pixels = p.pixel_array
-        except:
-            print('Pixels could not be read, possibly due to compression. Decompressing now...')
-            self.dcm_file = decompress(self.dcm_file)
-            p = pydicom.dcmread(self.dcm_file)
-            pixels = p.pixel_array
-        pixels = pixels.astype(float)
+        if p.file_meta.TransferSyntaxUID.is_compressed:
+            p.decompress()
+        pixels = p.pixel_array
         pixels = pixels * p.RescaleSlope + p.RescaleIntercept
         pixels = self.apply_ct_window(pixels, [400, 50])
+        pixels = pixels.astype(float)
         pixels_org = pixels.copy()
         converter = tag2numpy.Tag2NumPy(pixels.shape)
         converter.set_input_tag_file_path(self.tag_file)
